(principal-components data n)Get's the data as a list of lists where each list inside the bigger list represents a row of data
Selects the n number of principal compoennts
Get's the data as a list of lists where each list inside the bigger list represents a row of data Selects the `n` number of principal compoennts
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |